%% SETORG
function [xltkm,xlnkm] = setorg(dlat,dum1,dum2)
%  Establishes the spherical earth short distance conversion factors
%
%  Usage
%    [xltkm,xlnkm] = setorg(dlat,dlon)
%  Inputs
%    DLAT - Decimal latitude
%    DUM1 - Old inputs (not used)
%    DUM2 - Old inputs (not used)
%  Outputs
%    XLTKM - One minute of latitude in kilometers
%    XLNKM - One minute of longitude in kilometers

%-----------------------------------------------------------------------
%     forced to use spherical instead of elliptical reference.
%                                        drt, (july, 1989)
%-----------------------------------------------------------------------
%     cleaned up and added help          wsdw, (aug, 2009)
%-----------------------------------------------------------------------

facd_sphere = 111.19;
dlat_center = dlat;

xltkm = facd_sphere / 60.;
xlnkm = facd_sphere * cos (abs(dlat_center) * pi/180.) / 60.;
end



